==> arelle_release-2.37.35.tar.gz: arelle_release-2.37.35/tests/integration_tests/validation/conformance_suite_configurations/edinet.py <==
from pathlib import PurePath, Path

from tests.integration_tests.validation.conformance_suite_config import ConformanceSuiteConfig, ConformanceSuiteAssetConfig

config = ConformanceSuiteConfig(
    args=[
        '--baseTaxonomyValidation', 'none',
        '--disclosureSystem', 'EDINET',
    ],
    assets=[
        ConformanceSuiteAssetConfig.local_conformance_suite(
            Path('edinet'),
            entry_point=Path('index.xml'),
        ),
    ],
    cache_version_id='cs2wODrDheJqDIm1kEU4Qwk8jwd7DfQu',
    expected_additional_testcase_errors={f"*{s}": val for s, val in {
        # Duplicate errors: Running EDINET validations in a testcase context
        # prevents us from detecting when two models are being validated
        # from the same variation, so `shouldValidateUpload` always returns `True`.
        # This leads to any rule that validates at the package level (rather than the
        # instance level) firing once for each instance. Normal validation runs
        # do not have this issue. We can expect this to be resolved at some point.
        # Until then, if you construct a test case zip from a valid package that has multiple instances
        # (e.g. PublicDoc + AuditDoc) you'll need to add expected additional testcases here
        # for the duplicate errors.
        # TODO: Prevent duplicate runs in testcase context.
        "EC5806E/index.xml:invalid01": {
            # The duplicated instance needed to trigger the duplicated "preferredFilename"
            # error also causes the validation to fire an additional time in the conformance
            # suite context.
            "EDINET.EC5806E": 1,
        }
    }.items()},
    expected_failure_ids=frozenset([]),
    info_url='https://disclosure2.edinet-fsa.go.jp/weee0020.aspx',
    name=PurePath(__file__).stem,
    network_or_cache_required=False,
    plugins=frozenset({'validate/EDINET', 'inlineXbrlDocumentSet'}),
    shards=4,
    test_case_result_options='match-all',
)

==> arelle_release-2.37.45.tar.gz: arelle_release-2.37.45/tests/integration_tests/validation/conformance_suite_configurations/edinet.py <==
from pathlib import PurePath, Path

from tests.integration_tests.validation.conformance_suite_config import ConformanceSuiteConfig, ConformanceSuiteAssetConfig

config = ConformanceSuiteConfig(
    args=[
        '--baseTaxonomyValidation', 'none',
        '--disclosureSystem', 'EDINET',
        '--testcaseResultsCaptureWarnings',
    ],
    assets=[
        ConformanceSuiteAssetConfig.local_conformance_suite(
            Path('edinet'),
            entry_point=Path('index.xml'),
        ),
    ],
    cache_version_id='cs2wODrDheJqDIm1kEU4Qwk8jwd7DfQu',
    expected_additional_testcase_errors={f"*{s}": val for s, val in {
        # Duplicate errors: Running EDINET validations in a testcase context
        # prevents us from detecting when two models are being validated
        # from the same variation, so `shouldValidateUpload` always returns `True`.
        # This leads to any rule that validates at the package level (rather than the
        # instance level) firing once for each instance. Normal validation runs
        # do not have this issue. We can expect this to be resolved at some point.
        # Until then, if you construct a test case zip from a valid package that has multiple instances
        # (e.g. PublicDoc + AuditDoc) you'll need to add expected additional testcases here
        # for the duplicate errors.
        # TODO: Prevent duplicate runs in testcase context.

        # EDINET.EC8027W: Some of our "valid" documents define presentation and/or definition
        # links with multiple root elements. Keeping these out of the conformance suite
        # until we are more confident in our interpretation of the EDINET rule.

        "EC5806E/index.xml:invalid01": {
            # The duplicated instance needed to trigger the duplicated "preferredFilename"
            # error also causes the validation to fire an additional time in the conformance
            # suite context.
            "EDINET.EC5806E": 1,
        },
        "EC8024E/index.xml:invalid01": {
            "EDINET.EC8027W": 1,
        },
        "EC8062W/index.xml:invalid01": {
            "EDINET.EC8027W": 1,
        },
        "valid/index.xml:valid01": {
            "EDINET.EC8027W": 2,
        },
        "valid/index.xml:valid02": {
            "EDINET.EC8027W": 2,
        },
        "valid/index.xml:valid03": {
            "EDINET.EC8027W": 1,
        },
        "valid/index.xml:valid20": {
            "EDINET.EC8027W": 2,
        },
    }.items()},
    expected_failure_ids=frozenset([]),
    info_url='https://disclosure2.edinet-fsa.go.jp/weee0020.aspx',
    name=PurePath(__file__).stem,
    network_or_cache_required=False,
    plugins=frozenset({'validate/EDINET', 'inlineXbrlDocumentSet'}),
    shards=4,
    test_case_result_options='match-all',
)
